#!/bin/bash
# grab assignment tag for each student

. $(dirname $0)/config.sh

echo "Get assignment tag for each student"
if [[ $# != 1 ]]; then
	echo "Usage: $0 <assignment tag>"
	exit
fi
tag=$1			# e.g. assn1; tag name will be assn1/gitid
branch=grade/$1	# branch name will be grade/assn1/gitid

# handle each student by github ID
for user in ${GITIDS[@]}; do
	echo -en "\n$user "

	# SHA for remote tag, local tag, and branch
	remoteSHA=$(git ls-remote $user $tag | cut -f 1)
	localSHA=$(git show-ref -s refs/tags/$tag/$user)
	branchSHA=$(git show-ref -s refs/heads/grade/$tag/$user)

	# done if we already have a branch and the tag didn't change
	[[ "$branchSHA" != "" && "$remoteSHA" == "$localSHA" ]] && 
		continue

	# tag moved? delete the old one
	[[ "$localSHA" != "" && "$remoteSHA" != "$localSHA" ]] && 
		git tag -d $tag/$user >/dev/null 2>&1 && localSHA=""

	# try to fetch local tag
	[[ "$localSHA" == "" ]] && {
		git fetch $SHALLOW --no-tags "$user" "refs/tags/$tag:refs/tags/$tag/$user" >/dev/null 2>&1 ||
		echo -n "not found"
	}

	# if tag fetch was successful, set up or update branch
	git show-ref -s "refs/tags/$tag/$user" >/dev/null 2>&1 && {
		git checkout -f "$branch/$user" >/dev/null 2>&1 &&
		git merge -q "$tag/$user" ||
		git checkout -f -b "$branch/$user" "$tag/$user"
	}

done

echo -e "\n\nSubmit times:"
for user in ${GITIDS[@]}; do 
	git show-ref -s "refs/tags/$tag/$user" >/dev/null 2>&1 && {
		printf "%-20s: " $user;
		echo $(git log -1 --format="format:%cD" $tag/$user)
	}
done

echo