#!/bin/bash
# grab assignment tag for each student

. $(dirname $0)/config.sh

echo "Submit assignment grade for each student"
if [[ $# != 1 ]]; then
	echo "Usage: $0 <assignment tag>"
	exit
fi
tag=$1			# e.g. assn1; tag name will be assn1/gitid
branch=grade/$1	# branch name will be grade/assn1/gitid

# handle each student by github ID
for user in ${GITIDS[@]}; do
	echo -en "\n$user "

	# check for git repository for this user
	git rev-parse --q "refs/heads/github/$user" >/dev/null 2>&1 || {
		echo "github/$user not found"
		continue;
	}

	# check for grading branch for this user
	git rev-parse --q "refs/heads/$branch/$user" >/dev/null 2>&1 || {
		echo "$branch/$user not found"
		continue;
	}

	# switch to user's main git repository branch and bring up to date
	git checkout -f "github/$user"
	git pull

	# merge with grading branch and (if no conflict) push back to github
	git merge "$branch/$user" -m "$tag grades" && 
		git push $user HEAD:$MASTER
done

# switch back to master branch
echo -e "\n\n"
git checkout -f $MASTER
